@@ -40,7 +40,6 @@ class DashboardExtension(LavaServerExtension):
         menu = super(DashboardExtension, self).get_menu()
         menu.sub_menu = [
             Menu("About", reverse(self.main_view_name)),
-            Menu("Image Status", reverse("dashboard_app.views.image_status_list")),
             Menu("Testing Efforts", reverse("dashboard_app.views.testing_effort_list")),
             Menu("Bundle Streams", reverse("dashboard_app.views.bundle_stream_list")),
             Menu("Tests", reverse("dashboard_app.views.test_list")),
@@ -53,25 +52,9 @@ class DashboardExtension(LavaServerExtension):
         return "dashboard_app/front_page_snippet.html"
 
     def get_front_page_context(self):
-        from dashboard_app.models import (DataReport, ImageHealth)
+        from dashboard_app.models import DataReport
         return {
             'report_list': DataReport.repository.filter(front_page=True),
-            'interesting_images': [
-                ImageHealth('nano', 'panda'),
-                ImageHealth('nano', 'omap3'),
-                ImageHealth('nano', 'lt-panda'),
-                ImageHealth('developer', 'panda'),
-                ImageHealth('developer', 'omap3'),
-                ImageHealth('developer', 'lt-panda'),
-                ImageHealth('alip', 'panda'),
-                ImageHealth('alip', 'omap3'),
-                ImageHealth('alip', 'lt-panda'),
-                ImageHealth('alip', 'lt-panda-x11-base-natty'),
-                ImageHealth('ubuntu-desktop', 'panda'),
-                ImageHealth('ubuntu-desktop', 'omap3'),
-                ImageHealth('ubuntu-desktop', 'lt-panda'),
-                ImageHealth('ubuntu-desktop', 'lt-panda-x11-base-natty'),
-            ]
         }
 
     @property
@@ -96,11 +79,11 @@ class DashboardExtension(LavaServerExtension):
             'linaro_django_pagination.middleware.PaginationMiddleware')
         root_dir = os.path.normpath(os.path.join(os.path.dirname(__file__), ".."))
         settings_module['DATAVIEW_DIRS'] = [
-            os.path.join(root_dir, 'examples/views'),
-            os.path.join(root_dir, 'production/views')]
+            os.path.join(root_dir, 'examples', 'views'),
+            os.path.join(root_dir, 'production', 'views')]
         settings_module['DATAREPORT_DIRS'] = [
-            os.path.join(root_dir, 'examples/reports'),
-            os.path.join(root_dir, 'production/reports')]
+            os.path.join(root_dir, 'examples', 'reports'),
+            os.path.join(root_dir, 'production', 'reports')]
 
     def contribute_to_settings_ex(self, settings_module, settings_object):
         settings_module['DATAVIEW_DIRS'] = settings_object._settings.get(
