@@ -6,6 +6,10 @@ from django.db import models
 
 class Migration(SchemaMigration):
 
+    depends_on = (
+        ("lava_projects", "0001_add_model_Project"),
+    )
+
     def forwards(self, orm):
         
         # Adding model 'TestingEffort'
