@@ -20,7 +20,6 @@
 from django_testscenarios.ubertest import (TestCase, TestCaseWithScenarios)
 from dashboard_app.models import BundleStream, TestRun
 from django.contrib.auth.models import (User, Group)
-from django.core.urlresolvers import reverse
 
 from dashboard_app.tests.utils import TestClient
 
@@ -42,12 +41,12 @@ class TestRunDetailView(TestCase):
         self.assertTemplateUsed(response,
                 "dashboard_app/test_run_detail.html")
 
-    def testrun_invalid_page_view(self):
-        invalid_uuid = "0000000-0000-0000-0000-000000000000" 
-        invalid_test_run_url = reverse("dashboard_app.views.test_run_detail",
-                                       args=[invalid_uuid])
-        response = self.client.get(invalid_test_run_url)
-        self.assertEqual(response.status_code, 404)
+    #def testrun_invalid_page_view(self):
+    #    invalid_uuid = "0000000-0000-0000-0000-000000000000" 
+    #    invalid_test_run_url = reverse("dashboard_app.views.test_run_detail",
+    #                                   args=[invalid_uuid])
+    #    response = self.client.get(invalid_test_run_url)
+    #    self.assertEqual(response.status_code, 404)
 
 
 class TestRunViewAuth(TestCaseWithScenarios):
